pub enum SelfMode {
None,
Shared,
Mutable,
}Expand description
Whether a function is a plain function, or a method with a self
receiver (spec 2.5): self is a shared borrow, mut self a mutable
borrow. There is no owned self in milestone 2.
Variants