pub struct Function {
pub attrs: Vec<Attribute>,
pub name: Ident,
pub is_pub: bool,
pub self_mode: SelfMode,
pub self_span: Option<Span>,
pub params: Vec<Param>,
pub return_type: Option<TypeExpr>,
pub body: Block,
pub span: Span,
}Expand description
fn name(params) -> ReturnType { body }, optionally pub. Inside an
impl block the parameter list may start with a self receiver
(self_mode), which is never a Param (spec 2.5).
Fields
attrs: Vec<Attribute>name: Identis_pub: boolself_mode: SelfModeself_span: Option<Span>The self keyword of the receiver, where a mut fix-it inserts;
None exactly when self_mode is SelfMode::None.
params: Vec<Param>return_type: Option<TypeExpr>body: Blockspan: SpanTrait Implementations
impl StructuralPartialEq for Function